Small no_std-lib that checks if the binary is running inside a QEMU virtual machine.
Only works on x86/x86_64 platform. There are no heap allocation required.
Under the hood, this is a wrapper around the awesome crate https://crates.io/crates/raw-cpuid.
Enums
- Qemu
Certainty - Result of
runs_inside_qemuthat tells with what certainty the code runs inside QEMU.
Functions
- runs_
inside_ qemu - Returns if the code is running inside a QEMU virtual machine.
See
QemuCertainty, which is the return type.